"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const webpack_1 = require("webpack");
const webpack_2 = __importDefault(require("webpack"));
/*
  This does pattern replacement in the *output* bundles, so it can replace
  webpack's own emitted code, rather than just replacing things in app code.
*/
class ReplacePlugin {
    constructor(patterns) {
        this.patterns = patterns;
    }
    apply(compiler) {
        compiler.hooks.compilation.tap('EAIReplacePlugin', (compilation) => {
            compilation.hooks.processAssets.tap({
                name: 'EAIReplacePlugin',
                stage: webpack_1.Compilation.PROCESS_ASSETS_STAGE_ADDITIONS,
            }, () => {
                for (let chunk of compilation.chunks) {
                    for (let file of chunk.files) {
                        compilation.updateAsset(file, (old) => {
                            let replaced = new webpack_2.default.sources.ReplaceSource(old);
                            let input = old.source().toString();
                            for (let [pattern, replacement] of this.patterns) {
                                for (let match of input.matchAll(pattern)) {
                                    replaced.replace(match.index, match.index + match[0].length - 1, replacement);
                                }
                            }
                            return replaced;
                        });
                    }
                }
            });
        });
    }
}
exports.default = ReplacePlugin;
//# sourceMappingURL=replace-plugin.js.map